@@ -82,7 +82,10 @@ class Clade:
 
     def __check_write_to_parent_dir(self, path):
         # dirname can be empty if cmds_file is located in the current directory
-        parent_path = "." if not os.path.dirname(path) else os.path.dirname(path)
+        parent_path = os.path.dirname(path)
+
+        if not parent_path:
+            parent_path = os.getcwd()
 
         self.__check_write_to_dir(parent_path)
 
@@ -97,7 +100,11 @@ class Clade:
         self.__check_write_to_parent_dir(self.cmds_file)
 
         # Create path to the cmds.txt file
-        cmds_file_dirname = "." if not os.path.dirname(self.cmds_file) else os.path.dirname(self.cmds_file)
+        cmds_file_dirname = os.path.dirname(self.cmds_file)
+
+        if not cmds_file_dirname:
+            cmds_file_dirname = os.getcwd()
+
         os.makedirs(cmds_file_dirname, exist_ok=True)
 
     def __dump_conf(self):
@@ -456,7 +463,7 @@ class Clade:
         Args:
             file: A name of the source file from the source graph
         """
-        return (cmd_id for cmd_id in self.SrcGraph.load_src_graph([file])[file]['compiled_in'])
+        return (cmd_id for cmd_id in self.SrcGraph.load_src_graph([file])[file]["compiled_in"])
 
     def get_compilation_cmds_by_file(self, file):
         """Get list of compilation commands in which the file was compiled.
@@ -541,7 +548,7 @@ class Clade:
             files = set(files)
 
             if add_unknown:
-                files.add('unknown')
+                files.add("unknown")
 
         return self.Callgraph.load_callgraph(files)
 
@@ -578,7 +585,7 @@ class Clade:
             files = set(files)
 
             if add_unknown:
-                files.add('unknown')
+                files.add("unknown")
 
         return self.Functions.load_functions_by_file(files)
 
@@ -731,7 +738,12 @@ class Clade:
 
     def get_version(self):
         """Get the version of Clade that was used to create specified working directory."""
-        return self.get_meta()["clade_version"]
+        meta = self.get_meta()
+
+        if "versions" in meta:
+            return meta["versions"]["clade"]
+        else:
+            return meta.get("clade_version", "unknown")
 
     def get_meta_by_key(self, key):
         """Get meta information by its key"""
